@@ -80,14 +80,15 @@ class NetworkUtils(baseutils.BaseUtilsVirt):
 
     _VNIC_LISTENER_TIMEOUT_MS = 2000
 
+    _switches = {}
+    _switch_ports = {}
+    _vlan_sds = {}
+    _vsid_sds = {}
+    _sg_acl_sds = {}
+
     def __init__(self):
         super(NetworkUtils, self).__init__()
         self._jobutils = jobutils.JobUtils()
-        self._switches = {}
-        self._switch_ports = {}
-        self._vlan_sds = {}
-        self._vsid_sds = {}
-        self._sg_acl_sds = {}
 
     def init_caches(self):
         for vswitch in self._conn.Msvm_VirtualEthernetSwitch():
@@ -123,6 +124,9 @@ class NetworkUtils(baseutils.BaseUtilsVirt):
             port.ElementName: port for port in
             self._conn.Msvm_EthernetPortAllocationSettingData()}
 
+    def clear_port_sg_acls_cache(self, switch_port_name):
+        self._sg_acl_sds.pop(switch_port_name, None)
+
     def get_vswitch_id(self, vswitch_name):
         vswitch = self._get_vswitch(vswitch_name)
         return vswitch.Name
